import 'package:flutter/material.dart';
import 'package:softcorp_flutter_core/default_card/default_card.dart';
import 'package:softcorp_flutter_core/text_theme/text_theme.dart';

import '../constants.dart';

class DefaultFormField extends StatefulWidget {
  final TextEditingController textEditingController;
  final TextInputType textInputType;
  final String hint;
  final String label;
  final String? Function(String?)? validator;
  final BoxConstraints? constraints;
  final int? numberOfLines;
  final bool? disabled;
  final bool? addDefaultBorder;
  final Color? labelColor;
  final IconData? prefixIcon;
  final bool? obscureText;

  const DefaultFormField({
    Key? key,
    required this.textEditingController,
    required this.textInputType,
    required this.hint,
    required this.label,
    this.validator,
    this.addDefaultBorder,
    this.constraints,
    this.numberOfLines,
    this.disabled,
    this.labelColor,
    this.prefixIcon,
    this.obscureText,
  }) : super(key: key);

  @override
  State<StatefulWidget> createState() {
    return _DefaultFormFieldState();
  }
}

class _DefaultFormFieldState extends State<DefaultFormField> {
  bool isActive = false;
  Color shadowColor = defaultShadow;
  double elevation = defaultElevation;

  @override
  void initState() {
    super.initState();
  }

  setDefault() {
    setState(() {
      isActive = false;
      shadowColor = defaultShadow;
      elevation = defaultElevation;
    });
  }

  setActive() {
    setState(() {
      isActive = true;
      shadowColor = softcorpPrimaryColor;
      elevation = 10;
    });
  }

  setDanger() {
    setState(() {
      isActive = false;
      shadowColor = defaultDangerColor;
      elevation = 10;
    });
  }

  @override
  Widget build(BuildContext context) {
    return Padding(
      padding: const EdgeInsets.all(7.5),
      child: Column(
        crossAxisAlignment: CrossAxisAlignment.start,
        mainAxisAlignment: MainAxisAlignment.start,
        children: [
          caption(
            text: widget.label,
            context: context,
            color: widget.labelColor ?? defaultSubTitleColor,
          ),
          const SizedBox(height: 5),
          DefaultCard(
            shadowColor: shadowColor,
            elevation: elevation,
            child: Focus(
              onFocusChange: (hasFocus) {
                if (hasFocus == true) {
                  print("get in here...");
                  setState(() {
                    isActive = true;
                    shadowColor = softcorpPrimaryColor;
                    elevation = 10;
                  });
                } else {
                  print("get in here... 2");
                  setState(() {
                    isActive = false;
                    shadowColor = defaultShadow;
                    elevation = defaultElevation;
                  });
                }
              },
              child: TextFormField(
                enabled: widget.disabled == null ? true : (widget.disabled),
                controller: widget.textEditingController,
                obscureText: widget.obscureText ?? false,
                keyboardType: widget.textInputType,
                style: const TextStyle(color: Colors.black),
                decoration: InputDecoration(
                  hintText: widget.hint,
                  hoverColor: Colors.white,
                  enabledBorder:
                      const OutlineInputBorder(borderSide: BorderSide.none),
                  focusedBorder:
                      const OutlineInputBorder(borderSide: BorderSide.none),
                  errorBorder:
                      const OutlineInputBorder(borderSide: BorderSide.none),
                  focusedErrorBorder:
                      const OutlineInputBorder(borderSide: BorderSide.none),
                  hintStyle: const TextStyle(fontSize: 16, color: Colors.grey),
                  filled: true,
                  prefixIcon: widget.prefixIcon != null
                      ? Icon(
                          widget.prefixIcon,
                          size: 15,
                          color: defaultSubTitleColor,
                        )
                      : null,
                  contentPadding: const EdgeInsets.all(16),
                  fillColor:
                      widget.disabled == true ? Colors.grey[200] : Colors.white,
                ),
                validator: (String? val) {
                  if (widget.validator == null) {
                    return null;
                  }
                  String? validator = widget.validator!(val);
                  if (validator != null) {
                    setDanger();
                  }
                  return validator;
                },
                maxLines: widget.obscureText == true ? 1 : widget.numberOfLines,
              ),
            ),
          ),
        ],
      ),
    );
  }
}
